LocaleData class

Data class representing locale-specific information.

Constructors

LocaleData({required String languageCode, required bool isRTL, String? countryCode, String? scriptCode})
Creates a new LocaleData instance.
const
LocaleData.fromLanguageCode(String languageCode)
Creates LocaleData from a language code.
factory

Properties

countryCode String?
The country code if available (e.g., 'US', 'GB')
final
hashCode int
The hash code for this object.
no setteroverride
isRTL bool
Whether this locale uses right-to-left text direction
final
languageCode String
The locale identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptCode String?
The script code if available (e.g., 'Latn', 'Cyrl')
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override